
rm(list=ls()) #clear environment

library(multiwayvcov)
library(lmtest)
library(stargazer)
library(effects)

#set working directory

load("Physio.w.Survey.pub.Rdata") #panel dataset
load("Survey.w.Physio.pub.Rdata") #individual-level dataset

#new spending measures in individual-level dataset
Sp$spend_left <- Sp$spend_educ + Sp$spend_heduc + Sp$spend_health + Sp$spend_poor
Sp$spend_right <- Sp$spend_police + Sp$spend_terror
Sp$spend_rl <- Sp$spend_right - Sp$spend_left
Sp$spend_all <- Sp$spend_right + Sp$spend_left
Sp$spend_terror.poor <- Sp$spend_terror - Sp$spend_poor
Sp$spend_police.poor <- Sp$spend_police - Sp$spend_poor

#Figure 1
pdf("figure1.pdf", width = 5, height = 5)
hist(Sp$gslmc.negbias,breaks=seq(-.225,.225,.025),xlab="Threat Sensitivity",las=1,main=" ")
dev.off()

#Table 1
model5 <- lm(spend_terror.poor ~ gslmc.negbias, data=Sp)
model6 <- lm(spend_terror.poor ~ gslmc.negbias + dem + rep , data=Sp)
stargazer(model5,model6,type="text",no.space=TRUE,star.cutoffs=c(.05,.01,.001))
stargazer(model5,model6,type="latex",no.space=TRUE,star.cutoffs=c(.05,.01,.001),out="table1.tex")

#Figure 2
eff1 <- effect("gslmc.negbias", model6, typical=mean, xlevels = list(gslmc.negbias=c(-.1-.075,-.05,-.025,0,.025,.05,.075,.1,.125,.15,.175,.2)))
eff1r <- cbind(eff1$x,fit=eff1$fit,lower=eff1$lower,higher=eff1$upper)
poly <- c(eff1r$gslmc.negbias,rev(eff1r$gslmc.negbias))
gon <- c(eff1r$lower,rev(eff1r$higher))
polyg <- as.data.frame(cbind(poly,gon))
pdf("figure2.pdf", width = 5, height = 5)
plot(eff1r$gslmc.negbias, eff1r$fit,  type="n", ann=F, axes=F,ylim=c(-40,20),xlim=c(-.2,.2))
polygon(polyg$poly,polyg$gon,border=NA,col="gray",density=36,angle=90)
lines(eff1r$gslmc.negbias, eff1r$fit,  type="l", col="firebrick3",lwd=4)
axis(side=2, las=1, cex.axis=.8, col="gray")
mtext(side=2,expression(paste("Right-Left Spending Pref")),cex=1,line=3)
axis(side=1, las=1, cex.axis=.8, col="gray", padj=.8)
mtext(side=1,"Threat Sensitivity",cex=1,line=3)
dev.off()

#Table 2
model1 <- lm(gslmc ~ storyF, data=Ps)
m1.vcov<-cluster.vcov(model1,Ps$resp)
cl.se1 <- coeftest(model1,m1.vcov) 
model2 <- lm(gslmc ~ storyF + order, data=Ps)
m2.vcov<-cluster.vcov(model2,Ps$resp)
cl.se2 <- coeftest(model2,m2.vcov) 
stargazer(model1,model2,se=list(cl.se1[,2],cl.se2[,2]),type="text",no.space=T,star.cutoffs=c(.05,.01,.001))
stargazer(model1,model2,se=list(cl.se1[,2],cl.se2[,2]),type="latex",no.space=T,star.cutoffs=c(.05,.01,.001),out="table2.tex")

#Table 3
model5 <- lm(spend_rl ~ gslmc.negbias, data=Sp)
model6 <- lm(spend_rl ~ gslmc.negbias + dem + rep , data=Sp)
stargazer(model5,model6,type="text",no.space=TRUE,star.cutoffs=c(.05,.01,.001))
stargazer(model5,model6,type="latex",no.space=TRUE,star.cutoffs=c(.05,.01,.001),out="table3.tex")

#Table 4
model5 <- lm(spend_police.poor ~ gslmc.negbias, data=Sp)
model6 <- lm(spend_police.poor ~ gslmc.negbias + dem + rep , data=Sp)
stargazer(model5,model6,type="text",no.space=TRUE,star.cutoffs=c(.05,.01,.001))
stargazer(model5,model6,type="latex",no.space=TRUE,star.cutoffs=c(.05,.01,.001),out="table4.tex")



